@@ -29,24 +29,22 @@ class Square:
         size_meters = size_pixels * meters_per_pixel
         self._half_size_meters = size_meters / 2
 
-    def bounding_box_centered_on(
-        self, x_meters_center: Number, y_meters_center: Number
-    ) -> BoundingBox:
+    def bounding_box_centered_on(self, x_center_osgb: Number, y_center_osgb: Number) -> BoundingBox:
         """
         Get bounding box from a centre
 
         Args:
-            x_meters_center: x center of the bounding box
-            y_meters_center: y center of the bounding box
+            x_center_osgb: x center of the bounding box
+            y_center_osgb: y center of the bounding box
 
         Returns: Bounding box
 
         """
         return BoundingBox(
-            top=y_meters_center + self._half_size_meters,
-            bottom=y_meters_center - self._half_size_meters,
-            left=x_meters_center - self._half_size_meters,
-            right=x_meters_center + self._half_size_meters,
+            top=y_center_osgb + self._half_size_meters,
+            bottom=y_center_osgb - self._half_size_meters,
+            left=x_center_osgb - self._half_size_meters,
+            right=x_center_osgb + self._half_size_meters,
         )
 
 
